import { Type } from "igniteui-react-core";
/**
 * Enumeration used to identify the context menus for the [[Spreadsheet]]
 */
export declare enum SpreadsheetContextMenuArea {
    /**
     * The context menu for column headers in the [[Spreadsheet]] and for the cells when there is only a single range of columns selected.
     */
    Column = 0,
    /**
     * The context menu for row headers in the [[Spreadsheet]] and for the cells when there is only a single range of rows selected.
     */
    Row = 1,
    /**
     * The context menu for a cell selection in the [[Spreadsheet]].
     */
    Cell = 2,
    /**
     * The context menu for a Worksheet tab item in the [[Spreadsheet]].
     */
    Tab = 3,
    /**
     * The context menu for the control used to edit the cells within the [[Spreadsheet]].
     */
    InPlaceEditor = 4,
    /**
     * The context menu for the control within the FormulaBarControl that is used to edit the value of the active cell in the [[Spreadsheet]].
     */
    FormulaBarEditor = 5,
    /**
     * The context menu for the select all button at the intersection of the row and column header areas
     */
    SelectAllButton = 6,
    /**
     * The context menu for a cell selection in the [[Spreadsheet]] when the active cell is part of a [[WorksheetTable]].
     */
    TableCell = 7
}
/**
 * @hidden
 */
export declare let SpreadsheetContextMenuArea_$type: Type;
