import * as React from 'react';
import { IgPoint } from "igniteui-react-core";
import { Spreadsheet } from './Spreadsheet';
import { SpreadsheetAction } from './SpreadsheetAction';
import { SpreadsheetCell } from './SpreadsheetCell';
import { SpreadsheetCellEditMode } from './SpreadsheetCellEditMode';
import { SpreadsheetCellSelectionMode } from './SpreadsheetCellSelectionMode';
import { SpreadsheetChartAdapterBase } from './SpreadsheetChartAdapterBase';
import { SpreadsheetEnterKeyNavigationDirection } from './SpreadsheetEnterKeyNavigationDirection';
import { SpreadsheetPane } from './SpreadsheetPane';
import { SpreadsheetSelection } from './SpreadsheetSelection';
import { SpreadsheetCellRangeFormat } from './SpreadsheetCellRangeFormat';
import { WorksheetTable } from "igniteui-react-excel";
import { Worksheet } from "igniteui-react-excel";
import { Workbook } from "igniteui-react-excel";
import { UndoManager } from './UndoManager';
import { IgrSpreadsheetActionExecutedEventArgs } from './igr-spreadsheet-action-executed-event-args';
import { IgrSpreadsheetActionExecutingEventArgs } from './igr-spreadsheet-action-executing-event-args';
import { IgrSpreadsheetActiveCellChangedEventArgs } from './igr-spreadsheet-active-cell-changed-event-args';
import { IgrSpreadsheetActivePaneChangedEventArgs } from './igr-spreadsheet-active-pane-changed-event-args';
import { IgrSpreadsheetActiveTableChangedEventArgs } from './igr-spreadsheet-active-table-changed-event-args';
import { IgrSpreadsheetActiveWorksheetChangedEventArgs } from './igr-spreadsheet-active-worksheet-changed-event-args';
import { IgrSpreadsheetContextMenuOpeningEventArgs } from './igr-spreadsheet-context-menu-opening-event-args';
import { IgrSpreadsheetEditModeExitingEventArgs } from './igr-spreadsheet-edit-mode-exiting-event-args';
import { IgrSpreadsheetEditModeExitedEventArgs } from './igr-spreadsheet-edit-mode-exited-event-args';
import { IgrSpreadsheetEditModeEnteringEventArgs } from './igr-spreadsheet-edit-mode-entering-event-args';
import { IgrSpreadsheetEditModeEnteredEventArgs } from './igr-spreadsheet-edit-mode-entered-event-args';
import { IgrSpreadsheetEditModeValidationErrorEventArgs } from './igr-spreadsheet-edit-mode-validation-error-event-args';
import { IgrSpreadsheetEditRangePasswordNeededEventArgs } from './igr-spreadsheet-edit-range-password-needed-event-args';
import { IgrSpreadsheetHyperlinkExecutingEventArgs } from './igr-spreadsheet-hyperlink-executing-event-args';
import { IgrSpreadsheetSelectionChangedEventArgs } from './igr-spreadsheet-selection-changed-event-args';
import { IgrSpreadsheetUserPromptDisplayingEventArgs } from './igr-spreadsheet-user-prompt-displaying-event-args';
import { IgrSpreadsheetWorkbookDirtiedEventArgs } from './igr-spreadsheet-workbook-dirtied-event-args';
/**
 * Custom control that displays one or more worksheets.
*/
export declare class IgrSpreadsheet extends React.Component<IIgrSpreadsheetProps> {
    private _height;
    private _width;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    private _elRef;
    private _getMainRef;
    private _activeContainerElements;
    private _currentContainers;
    private _uniqueContainerId;
    private _removeContainer;
    private _createContainer;
    private _updateContainerState;
    render(): React.DetailedReactHTMLElement<{
        className: string;
        ref: (ref: any) => void;
        children: any[];
    }, any>;
    private _container;
    constructor(props: IIgrSpreadsheetProps);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    protected initializeProperties(): void;
    destroy(): void;
    componentWillUnmount(): void;
    private _initialized;
    private _wrapper;
    protected createImplementation(): Spreadsheet;
    private _spreadsheet;
    initializeContent(): void;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): Spreadsheet; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrSpreadsheet;
    /**
     * Returns an array of the panes for the activeWorksheet.
    */
    get panes(): SpreadsheetPane[];
    /**
 * Returns or sets a boolean indicating whether the scroll lock key is toggled.
 * This property is used when certain keys are pressed while the control has focus. For example
 * if an arrow key is pressed while the scroll lock is enabled the cell area will be scrolled rather than changing
 * the active cell.
 * Note:
 * This property is not maintained/changed by the control. It is just queried when
 * performing actions that consider whether the scroll lock is enabled.
*/
    get isScrollLocked(): boolean;
    set isScrollLocked(v: boolean);
    /**
     * Returns or sets the active cell within the selected worksheet.
    */
    get activeCell(): SpreadsheetCell;
    set activeCell(v: SpreadsheetCell);
    /**
     * Returns an object that represents the pane with the focus.
    */
    get activePane(): SpreadsheetPane;
    set activePane(v: SpreadsheetPane);
    /**
     * Returns an object that represents the current selection of the
     * activePane.
    */
    get activeSelection(): SpreadsheetSelection;
    set activeSelection(v: SpreadsheetSelection);
    /**
     * Returns an object used to get the formatting of the
     * activeCell and where modifications are applied to the entire
     * activeSelection.
     * Any changes made to this object will affect all the objects in the selection. So for example, the
     * Font.Name may return "Arial" because the active cell has that as its resolved font name even though the other
     * cells are using a different font but if you set the Font.Name of this object to "Arial" then all the objects
     * affected by the selection will have their Font.Name updated to that value.
    */
    get activeSelectionCellRangeFormat(): SpreadsheetCellRangeFormat;
    /**
     * Returns the
     * ig.excel.WorksheetTable associated with the
     * activeCell of the
     * activeWorksheet.
    */
    get activeTable(): WorksheetTable;
    set activeTable(v: WorksheetTable);
    /**
     * Returns or sets the Worksheet from the
     * workbook whose content should be displayed within the control.
    */
    get activeWorksheet(): Worksheet;
    set activeWorksheet(v: Worksheet);
    /**
     * Returns or sets a boolean indicating whether the spreadsheet allows adding worksheets.
    */
    get allowAddWorksheet(): boolean;
    set allowAddWorksheet(v: boolean);
    /**
     * Returns or sets a boolean indicating whether the spreadsheet allows deleting worksheets.
    */
    get allowDeleteWorksheet(): boolean;
    set allowDeleteWorksheet(v: boolean);
    /**
     * Returns or sets a boolean indicating if the grid lines are displayed in the selected worksheets.
    */
    get areGridlinesVisible(): boolean;
    set areGridlinesVisible(v: boolean);
    /**
     * Returns or sets a boolean indicating if the row and column headers are displayed for the selected worksheets.
    */
    get areHeadersVisible(): boolean;
    set areHeadersVisible(v: boolean);
    /**
     * Returns an enumeration used to indicate the current edit mode state.
    */
    get cellEditMode(): SpreadsheetCellEditMode;
    set cellEditMode(v: SpreadsheetCellEditMode);
    /**
     * Returns or sets the object that will provide the chart visualization for display within the
     * Spreadsheet
     * By default charts are not displayed within the spreadsheet. To display charts one should set this
     * property to an instance of a
     * SpreadsheetChartAdapter
     * which is in a separate reference since it relies upon
     * the chart and other data visualization controls.
    */
    get chartAdapter(): SpreadsheetChartAdapterBase;
    set chartAdapter(v: SpreadsheetChartAdapterBase);
    /**
     * Returns or sets an enumeration indicating the direction of the cell adjacent to the
     * activeCell that should be activated when the enter key is pressed.
     * This property is only used if the
     * isEnterKeyNavigationEnabled is set to true. Also, the reverse direction is
     * navigated when Shift + Enter are pressed.
    */
    get enterKeyNavigationDirection(): SpreadsheetEnterKeyNavigationDirection;
    set enterKeyNavigationDirection(v: SpreadsheetEnterKeyNavigationDirection);
    /**
     * Returns or sets the number of decimal places by which a whole number typed in during edit mode should be adjusted when
     * isFixedDecimalEnabled is true
    */
    get fixedDecimalPlaceCount(): number;
    set fixedDecimalPlaceCount(v: number);
    /**
     * Returns or sets a boolean indicating whether the adjacent cell indicated by the
     * enterKeyNavigationDirection should be navigated to when the enter key is pressed.
    */
    get isEnterKeyNavigationEnabled(): boolean;
    set isEnterKeyNavigationEnabled(v: boolean);
    /**
     * Returns or sets a boolean indicating whether a fixed decimal place is automatically added when a whole number is entered while in edit mode.
    */
    get isFixedDecimalEnabled(): boolean;
    set isFixedDecimalEnabled(v: boolean);
    /**
     * Returns or sets a boolean indicating if the formula bar is displayed within the
     * Spreadsheet.
    */
    get isFormulaBarVisible(): boolean;
    set isFormulaBarVisible(v: boolean);
    /**
     * Returns a boolean indicating if the control is currently editing the value of the
     * activeCell
    */
    get isInEditMode(): boolean;
    set isInEditMode(v: boolean);
    /**
     * Returns or sets a boolean indicating whether the control is in "End mode".
     * End mode is a mode that affects certain keyboard navigation such as navigating with the arrow keys. For example when in
     * end mode and one presses the right arrow, the
     * activeCell will be changed to be the first cell to the right of the current ActiveCell
     * that has a value (even if the value is ""). If there were no cells to the right with a value then it would activate the right most cell in that row. End
     * mode will end automatically such as when one presses an arrow key.
    */
    get isInEndMode(): boolean;
    set isInEndMode(v: boolean);
    /**
     * Returns a boolean indicating if the user is currently editing the name of the active worksheet.
    */
    get isRenamingWorksheet(): boolean;
    set isRenamingWorksheet(v: boolean);
    /**
     * Returns or sets a boolean indicating whether undo is enabled for the control.
    */
    get isUndoEnabled(): boolean;
    set isUndoEnabled(v: boolean);
    /**
     * Returns or sets the width of the name box within the formula bar.
    */
    get nameBoxWidth(): number;
    set nameBoxWidth(v: number);
    /**
     * Returns or sets a value indicating how the selection is updated when interacting with the cells via the mouse or keyboard.
    */
    get selectionMode(): SpreadsheetCellSelectionMode;
    set selectionMode(v: SpreadsheetCellSelectionMode);
    /**
     * Returns or sets an array of the Worksheets whose tabs are selected.
    */
    get selectedWorksheets(): Worksheet[];
    set selectedWorksheets(v: Worksheet[]);
    /**
     * Returns or sets the UndoManager.
     * Note:
     * this property can not be set to null.
    */
    get undoManager(): UndoManager;
    set undoManager(v: UndoManager);
    /**
     * Returns or sets the position of the screen tip used to display the input message for the data validation rule associated with the active cell.
    */
    get validationInputMessagePosition(): IgPoint;
    set validationInputMessagePosition(v: IgPoint);
    /**
     * Returns or sets the
     * workbook whose information is displayed in the control.
    */
    get workbook(): Workbook;
    set workbook(v: Workbook);
    /**
     * Returns or sets the magnification of the selected worksheets.
    */
    get zoomLevel(): number;
    set zoomLevel(v: number);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Notifies the spreadsheet that the container object has been resized.

*/
    containerResized(): void;
    /**
     * Executes the specified action.
    
    * @param action  * Identifies the action to be performed.
    */
    executeAction(action: SpreadsheetAction): boolean;
    /**
     * Forces the spreadsheet to synchronously perform any deferred work.
    
    */
    flush(): void;
    /**
     * Notifies the spreadsheet that style information used for rendering may have been updated.
    
    */
    styleUpdated(): void;
    /**
     * Returns an object with information about the visual state of the spreadsheet.
    
    */
    exportVisualData(): any;
    private _contextMenuOpening;
    private _contextMenuOpening_wrapped;
    /**
     * Invoked when a contextmenu is being opened for the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.menuArea" argType="string" Get the [area](ig.spreadsheet.SpreadsheetContextMenuArea) for which the menu is being displayed.
    */
    get contextMenuOpening(): (s: IgrSpreadsheet, e: IgrSpreadsheetContextMenuOpeningEventArgs) => void;
    set contextMenuOpening(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetContextMenuOpeningEventArgs) => void);
    private _ActionExecuted;
    private _ActionExecuted_wrapped;
    /**
     * Invoked when an action is executed on the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Gets the [action](ig.spreadsheet.SpreadsheetAction) that was executed.
    */
    get ActionExecuted(): (s: IgrSpreadsheet, e: IgrSpreadsheetActionExecutedEventArgs) => void;
    set ActionExecuted(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetActionExecutedEventArgs) => void);
    private _ActionExecuting;
    private _ActionExecuting_wrapped;
    /**
     * Invoked when an action is about to be executed by the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Gets the [action](ig.spreadsheet.SpreadsheetAction) that is about to be executed.
    */
    get ActionExecuting(): (s: IgrSpreadsheet, e: IgrSpreadsheetActionExecutingEventArgs) => void;
    set ActionExecuting(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetActionExecutingEventArgs) => void);
    private _activeCellChanged;
    private _activeCellChanged_wrapped;
    /**
     * Invoked when the
     * activeCell of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldValue" argType="string" Gets the previous active cell.
     * eventArgument="ui.newValue" argType="string" Gets the current active cell.
    */
    get activeCellChanged(): (s: IgrSpreadsheet, e: IgrSpreadsheetActiveCellChangedEventArgs) => void;
    set activeCellChanged(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetActiveCellChangedEventArgs) => void);
    private _activePaneChanged;
    private _activePaneChanged_wrapped;
    /**
     * Invoked when the
     * activePane of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActivePane" argType="object" Gets the previous active [pane](ig.spreadsheet.SpreadsheetPane).
     * eventArgument="ui.newActivePane" argType="object" Gets the current active [pane](ig.spreadsheet.SpreadsheetPane).
     * eventArgument="ui.activeCell" argType="string" Gets the active cell of the new active pane or null if there is no active pane.
     * eventArgument="ui.visibleRange" argType="string" Gets the current visible range of the new active pane or null if there is no active pane.
    */
    get activePaneChanged(): (s: IgrSpreadsheet, e: IgrSpreadsheetActivePaneChangedEventArgs) => void;
    set activePaneChanged(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetActivePaneChangedEventArgs) => void);
    private _activeTableChanged;
    private _activeTableChanged_wrapped;
    /**
     * Invoked when the
     * activeTable of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActiveTable" argType="object" Gets the previous active [Table](ig.excel.WorksheetTable).
     * eventArgument="ui.newActiveTable" argType="object" Gets the current active [Table](ig.excel.WorksheetTable).
    */
    get activeTableChanged(): (s: IgrSpreadsheet, e: IgrSpreadsheetActiveTableChangedEventArgs) => void;
    set activeTableChanged(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetActiveTableChangedEventArgs) => void);
    private _activeWorksheetChanged;
    private _activeWorksheetChanged_wrapped;
    /**
     * Invoked when the
     * activeWorksheet of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActiveWorksheet" argType="object" Gets the previous active [worksheet](ig.excel.Worksheet).
     * eventArgument="ui.oldActiveWorksheetName" argType="string" Gets the name of the previous active worksheet or null if oldActiveWorksheet is null.
     * eventArgument="ui.newActiveWorksheet" argType="object" Gets the current active [worksheet](ig.excel.Worksheet).
     * eventArgument="ui.newActiveWorksheetName" argType="string" Gets the name of the new active worksheet or null if newActiveWorksheet is null.
    */
    get activeWorksheetChanged(): (s: IgrSpreadsheet, e: IgrSpreadsheetActiveWorksheetChangedEventArgs) => void;
    set activeWorksheetChanged(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetActiveWorksheetChangedEventArgs) => void);
    private _editModeExiting;
    private _editModeExiting_wrapped;
    /**
     * Invoked when the
     * Spreadsheet is about to end the in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.acceptChanges" argType="bool" Get or set a boolean indicating whether the changes will be made to the cell's value when edit mode ends.
     * eventArgument="ui.canCancel" argType="bool" Get a boolean indicating if the edit mode is being forced to exit edit mode in which case it cannot be cancelled.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is exiting edit mode.
     * eventArgument="ui.editText" argType="string" Gets the edit text that will be used to update the cell(s).
    */
    get editModeExiting(): (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeExitingEventArgs) => void;
    set editModeExiting(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeExitingEventArgs) => void);
    private _editModeExited;
    private _editModeExited_wrapped;
    /**
     * Invoked when the
     * Spreadsheet has ended the in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control has exited edit mode.
    */
    get editModeExited(): (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeExitedEventArgs) => void;
    set editModeExited(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeExitedEventArgs) => void);
    private _editModeEntering;
    private _editModeEntering_wrapped;
    /**
     * Invoked when the
     * Spreadsheet is about to start in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is going into edit mode.
    */
    get editModeEntering(): (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeEnteringEventArgs) => void;
    set editModeEntering(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeEnteringEventArgs) => void);
    private _editModeEntered;
    private _editModeEntered_wrapped;
    /**
     * Invoked when the
     * Spreadsheet has started in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control has entered edit mode.
    */
    get editModeEntered(): (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeEnteredEventArgs) => void;
    set editModeEntered(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeEnteredEventArgs) => void);
    private _editModeValidationError;
    private _editModeValidationError_wrapped;
    /**
     * Invoked when the
     * Spreadsheet is exiting edit mode and the new value for the
     * activeCell is not valid based on the criteria of that cell's
     * ig.excel.DataValidationRule.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Get or set the [action](ig.spreadsheet.SpreadsheetEditModeValidationErrorAction)  to take in response to the failed validation.
     * eventArgument="ui.canStayInEditMode" argType="bool" Get a boolean indicating whether the cell is allowed to stay in edit mode.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is in edit mode.
     * eventArgument="ui.validationRule" argType="string" Get the [rule](ig.excel.DataValidationRule) which failed validation.
     * The EditModeValidationError is raised while exiting edit mode if the new value for the
     * activeCell is not valid based on the criteria of that cell's
     * ig.excel.DataValidationRule.
     * Since the rule needs to evaluate the value of the cell and potentially other cell's in the Worksheet, the value is first applied to the cell(s) and then is validated. By default if the event is not handled and the
     * showErrorMessageForInvalidValue is true, a message box will be displayed to the end user to determine what action to take. One can handle this event and specify the action that should
     * be taken using the action.
     * Note:
     * The validation rule will not be evaluated if edit mode is being cancelled such as when the user presses Escape to cancel edit.
     * Note:
     * The action will default to
     * AcceptChange
     * if the ShowErrorMessageForInvalidValue of the validationRule is false; otherwise it will default to
     * ShowPrompt
     * .
     * Note:
     * Like Microsoft Excel, only the validation rule of the active cell is considered even if the update is affecting other cells in the selection.
    */
    get editModeValidationError(): (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeValidationErrorEventArgs) => void;
    set editModeValidationError(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeValidationErrorEventArgs) => void);
    private _editRangePasswordNeeded;
    private _editRangePasswordNeeded_wrapped;
    /**
     * Invoked when the
     * Spreadsheet is performing an operation on a protected Worksheet and there is a single range that may be unlocked to allow the operation to be performed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.ranges" argType="array" Get an array of [protected range](ig.excel.WorksheetProtectedRange) objects that should be unlocked.
     * eventArgument="ui.unprotect" argType="object" Get a parameterless function that may be invoked to unlock the associated ranges.
    */
    get editRangePasswordNeeded(): (s: IgrSpreadsheet, e: IgrSpreadsheetEditRangePasswordNeededEventArgs) => void;
    set editRangePasswordNeeded(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetEditRangePasswordNeededEventArgs) => void);
    private _hyperlinkExecuting;
    private _hyperlinkExecuting_wrapped;
    /**
     * Invoked when a hyperlink is being followed in the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.hyperlink" argType="object" Get the [hyperlink](ig.excel.WorksheetHyperlink) to be executed.
    */
    get hyperlinkExecuting(): (s: IgrSpreadsheet, e: IgrSpreadsheetHyperlinkExecutingEventArgs) => void;
    set hyperlinkExecuting(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetHyperlinkExecutingEventArgs) => void);
    private _selectionChanged;
    private _selectionChanged_wrapped;
    /**
     * Invoked when the selection for a
     * ig.spreadsheet.SpreadsheetPane of the
     * Spreadsheet is changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.pane" argType="object" Get the [pane](ig.spreadsheet.SpreadsheetPane) for which the selection has changed.
    */
    get selectionChanged(): (s: IgrSpreadsheet, e: IgrSpreadsheetSelectionChangedEventArgs) => void;
    set selectionChanged(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetSelectionChangedEventArgs) => void);
    private _userPromptDisplaying;
    private _userPromptDisplaying_wrapped;
    /**
     * Invoked when the user will be prompted with a message regarding an operation that is being performed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.canCancel" argType="bool" Get a boolean indicating if the operation that triggered the prompt can be cancelled.
     * eventArgument="ui.displayMessage" argType="bool" Get a boolean indicating if a message will be displayed to the end user.
     * eventArgument="ui.exception" argType="object" Gets the exception for the error, if there was one.
     * eventArgument="ui.message" argType="string" Get or set the message that will be displayed.
     * eventArgument="ui.trigger" argType="string" Get the [action](ig.spreadsheet.SpreadsheetUserPromptTrigger) that caused the prompt to be displayed.
    */
    get userPromptDisplaying(): (s: IgrSpreadsheet, e: IgrSpreadsheetUserPromptDisplayingEventArgs) => void;
    set userPromptDisplaying(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetUserPromptDisplayingEventArgs) => void);
    private _workbookDirtied;
    private _workbookDirtied_wrapped;
    /**
     * Invoked when a change has been made to the
     * workbook that might require a save.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * Note:
     * This event is invoked asynchronously with regards to the change(s) that
     * have occurred. Also some changes alone are not considered to dirty the Workbook even though it
     * does change state on the Workbook or one of its subobjects. An example of that would be a zoom
     * type operation (e.g. changing the
     * magnificationInNormalView).
    */
    get workbookDirtied(): (s: IgrSpreadsheet, e: IgrSpreadsheetWorkbookDirtiedEventArgs) => void;
    set workbookDirtied(ev: (s: IgrSpreadsheet, e: IgrSpreadsheetWorkbookDirtiedEventArgs) => void);
}
export interface IIgrSpreadsheetProps {
    width?: string;
    height?: string;
    children?: React.ReactNode;
    /**
 * Returns or sets a boolean indicating whether the scroll lock key is toggled.
 * This property is used when certain keys are pressed while the control has focus. For example
 * if an arrow key is pressed while the scroll lock is enabled the cell area will be scrolled rather than changing
 * the active cell.
 * Note:
 * This property is not maintained/changed by the control. It is just queried when
 * performing actions that consider whether the scroll lock is enabled.
*/
    isScrollLocked?: boolean | string;
    /**
     * Returns or sets the active cell within the selected worksheet.
    */
    activeCell?: SpreadsheetCell;
    /**
     * Returns an object that represents the pane with the focus.
    */
    activePane?: SpreadsheetPane;
    /**
     * Returns an object that represents the current selection of the
     * activePane.
    */
    activeSelection?: SpreadsheetSelection;
    /**
     * Returns the
     * ig.excel.WorksheetTable associated with the
     * activeCell of the
     * activeWorksheet.
    */
    activeTable?: WorksheetTable;
    /**
     * Returns or sets the Worksheet from the
     * workbook whose content should be displayed within the control.
    */
    activeWorksheet?: Worksheet;
    /**
     * Returns or sets a boolean indicating whether the spreadsheet allows adding worksheets.
    */
    allowAddWorksheet?: boolean | string;
    /**
     * Returns or sets a boolean indicating whether the spreadsheet allows deleting worksheets.
    */
    allowDeleteWorksheet?: boolean | string;
    /**
     * Returns or sets a boolean indicating if the grid lines are displayed in the selected worksheets.
    */
    areGridlinesVisible?: boolean | string;
    /**
     * Returns or sets a boolean indicating if the row and column headers are displayed for the selected worksheets.
    */
    areHeadersVisible?: boolean | string;
    /**
     * Returns an enumeration used to indicate the current edit mode state.
    */
    cellEditMode?: SpreadsheetCellEditMode;
    /**
     * Returns or sets the object that will provide the chart visualization for display within the
     * Spreadsheet
     * By default charts are not displayed within the spreadsheet. To display charts one should set this
     * property to an instance of a
     * SpreadsheetChartAdapter
     * which is in a separate reference since it relies upon
     * the chart and other data visualization controls.
    */
    chartAdapter?: SpreadsheetChartAdapterBase;
    /**
     * Returns or sets an enumeration indicating the direction of the cell adjacent to the
     * activeCell that should be activated when the enter key is pressed.
     * This property is only used if the
     * isEnterKeyNavigationEnabled is set to true. Also, the reverse direction is
     * navigated when Shift + Enter are pressed.
    */
    enterKeyNavigationDirection?: SpreadsheetEnterKeyNavigationDirection;
    /**
     * Returns or sets the number of decimal places by which a whole number typed in during edit mode should be adjusted when
     * isFixedDecimalEnabled is true
    */
    fixedDecimalPlaceCount?: number | string;
    /**
     * Returns or sets a boolean indicating whether the adjacent cell indicated by the
     * enterKeyNavigationDirection should be navigated to when the enter key is pressed.
    */
    isEnterKeyNavigationEnabled?: boolean | string;
    /**
     * Returns or sets a boolean indicating whether a fixed decimal place is automatically added when a whole number is entered while in edit mode.
    */
    isFixedDecimalEnabled?: boolean | string;
    /**
     * Returns or sets a boolean indicating if the formula bar is displayed within the
     * Spreadsheet.
    */
    isFormulaBarVisible?: boolean | string;
    /**
     * Returns a boolean indicating if the control is currently editing the value of the
     * activeCell
    */
    isInEditMode?: boolean | string;
    /**
     * Returns or sets a boolean indicating whether the control is in "End mode".
     * End mode is a mode that affects certain keyboard navigation such as navigating with the arrow keys. For example when in
     * end mode and one presses the right arrow, the
     * activeCell will be changed to be the first cell to the right of the current ActiveCell
     * that has a value (even if the value is ""). If there were no cells to the right with a value then it would activate the right most cell in that row. End
     * mode will end automatically such as when one presses an arrow key.
    */
    isInEndMode?: boolean | string;
    /**
     * Returns a boolean indicating if the user is currently editing the name of the active worksheet.
    */
    isRenamingWorksheet?: boolean | string;
    /**
     * Returns or sets a boolean indicating whether undo is enabled for the control.
    */
    isUndoEnabled?: boolean | string;
    /**
     * Returns or sets the width of the name box within the formula bar.
    */
    nameBoxWidth?: number | string;
    /**
     * Returns or sets a value indicating how the selection is updated when interacting with the cells via the mouse or keyboard.
    */
    selectionMode?: SpreadsheetCellSelectionMode;
    /**
     * Returns or sets an array of the Worksheets whose tabs are selected.
    */
    selectedWorksheets?: Worksheet[];
    /**
     * Returns or sets the UndoManager.
     * Note:
     * this property can not be set to null.
    */
    undoManager?: UndoManager;
    /**
     * Returns or sets the position of the screen tip used to display the input message for the data validation rule associated with the active cell.
    */
    validationInputMessagePosition?: IgPoint | string;
    /**
     * Returns or sets the
     * workbook whose information is displayed in the control.
    */
    workbook?: Workbook;
    /**
     * Returns or sets the magnification of the selected worksheets.
    */
    zoomLevel?: number | string;
    /**
 * Invoked when a contextmenu is being opened for the
 * Spreadsheet.
 * eventArgument="evt" argType="event" jQuery event object.
 * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
 * eventArgument="ui.menuArea" argType="string" Get the [area](ig.spreadsheet.SpreadsheetContextMenuArea) for which the menu is being displayed.
*/
    contextMenuOpening?: (s: IgrSpreadsheet, e: IgrSpreadsheetContextMenuOpeningEventArgs) => void;
    /**
     * Invoked when an action is executed on the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Gets the [action](ig.spreadsheet.SpreadsheetAction) that was executed.
    */
    ActionExecuted?: (s: IgrSpreadsheet, e: IgrSpreadsheetActionExecutedEventArgs) => void;
    /**
     * Invoked when an action is about to be executed by the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Gets the [action](ig.spreadsheet.SpreadsheetAction) that is about to be executed.
    */
    ActionExecuting?: (s: IgrSpreadsheet, e: IgrSpreadsheetActionExecutingEventArgs) => void;
    /**
     * Invoked when the
     * activeCell of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldValue" argType="string" Gets the previous active cell.
     * eventArgument="ui.newValue" argType="string" Gets the current active cell.
    */
    activeCellChanged?: (s: IgrSpreadsheet, e: IgrSpreadsheetActiveCellChangedEventArgs) => void;
    /**
     * Invoked when the
     * activePane of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActivePane" argType="object" Gets the previous active [pane](ig.spreadsheet.SpreadsheetPane).
     * eventArgument="ui.newActivePane" argType="object" Gets the current active [pane](ig.spreadsheet.SpreadsheetPane).
     * eventArgument="ui.activeCell" argType="string" Gets the active cell of the new active pane or null if there is no active pane.
     * eventArgument="ui.visibleRange" argType="string" Gets the current visible range of the new active pane or null if there is no active pane.
    */
    activePaneChanged?: (s: IgrSpreadsheet, e: IgrSpreadsheetActivePaneChangedEventArgs) => void;
    /**
     * Invoked when the
     * activeTable of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActiveTable" argType="object" Gets the previous active [Table](ig.excel.WorksheetTable).
     * eventArgument="ui.newActiveTable" argType="object" Gets the current active [Table](ig.excel.WorksheetTable).
    */
    activeTableChanged?: (s: IgrSpreadsheet, e: IgrSpreadsheetActiveTableChangedEventArgs) => void;
    /**
     * Invoked when the
     * activeWorksheet of the
     * Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActiveWorksheet" argType="object" Gets the previous active [worksheet](ig.excel.Worksheet).
     * eventArgument="ui.oldActiveWorksheetName" argType="string" Gets the name of the previous active worksheet or null if oldActiveWorksheet is null.
     * eventArgument="ui.newActiveWorksheet" argType="object" Gets the current active [worksheet](ig.excel.Worksheet).
     * eventArgument="ui.newActiveWorksheetName" argType="string" Gets the name of the new active worksheet or null if newActiveWorksheet is null.
    */
    activeWorksheetChanged?: (s: IgrSpreadsheet, e: IgrSpreadsheetActiveWorksheetChangedEventArgs) => void;
    /**
     * Invoked when the
     * Spreadsheet is about to end the in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.acceptChanges" argType="bool" Get or set a boolean indicating whether the changes will be made to the cell's value when edit mode ends.
     * eventArgument="ui.canCancel" argType="bool" Get a boolean indicating if the edit mode is being forced to exit edit mode in which case it cannot be cancelled.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is exiting edit mode.
     * eventArgument="ui.editText" argType="string" Gets the edit text that will be used to update the cell(s).
    */
    editModeExiting?: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeExitingEventArgs) => void;
    /**
     * Invoked when the
     * Spreadsheet has ended the in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control has exited edit mode.
    */
    editModeExited?: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeExitedEventArgs) => void;
    /**
     * Invoked when the
     * Spreadsheet is about to start in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is going into edit mode.
    */
    editModeEntering?: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeEnteringEventArgs) => void;
    /**
     * Invoked when the
     * Spreadsheet has started in-place editing of the
     * activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control has entered edit mode.
    */
    editModeEntered?: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeEnteredEventArgs) => void;
    /**
     * Invoked when the
     * Spreadsheet is exiting edit mode and the new value for the
     * activeCell is not valid based on the criteria of that cell's
     * ig.excel.DataValidationRule.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Get or set the [action](ig.spreadsheet.SpreadsheetEditModeValidationErrorAction)  to take in response to the failed validation.
     * eventArgument="ui.canStayInEditMode" argType="bool" Get a boolean indicating whether the cell is allowed to stay in edit mode.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is in edit mode.
     * eventArgument="ui.validationRule" argType="string" Get the [rule](ig.excel.DataValidationRule) which failed validation.
     * The EditModeValidationError is raised while exiting edit mode if the new value for the
     * activeCell is not valid based on the criteria of that cell's
     * ig.excel.DataValidationRule.
     * Since the rule needs to evaluate the value of the cell and potentially other cell's in the Worksheet, the value is first applied to the cell(s) and then is validated. By default if the event is not handled and the
     * showErrorMessageForInvalidValue is true, a message box will be displayed to the end user to determine what action to take. One can handle this event and specify the action that should
     * be taken using the action.
     * Note:
     * The validation rule will not be evaluated if edit mode is being cancelled such as when the user presses Escape to cancel edit.
     * Note:
     * The action will default to
     * AcceptChange
     * if the ShowErrorMessageForInvalidValue of the validationRule is false; otherwise it will default to
     * ShowPrompt
     * .
     * Note:
     * Like Microsoft Excel, only the validation rule of the active cell is considered even if the update is affecting other cells in the selection.
    */
    editModeValidationError?: (s: IgrSpreadsheet, e: IgrSpreadsheetEditModeValidationErrorEventArgs) => void;
    /**
     * Invoked when the
     * Spreadsheet is performing an operation on a protected Worksheet and there is a single range that may be unlocked to allow the operation to be performed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.ranges" argType="array" Get an array of [protected range](ig.excel.WorksheetProtectedRange) objects that should be unlocked.
     * eventArgument="ui.unprotect" argType="object" Get a parameterless function that may be invoked to unlock the associated ranges.
    */
    editRangePasswordNeeded?: (s: IgrSpreadsheet, e: IgrSpreadsheetEditRangePasswordNeededEventArgs) => void;
    /**
     * Invoked when a hyperlink is being followed in the
     * Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.hyperlink" argType="object" Get the [hyperlink](ig.excel.WorksheetHyperlink) to be executed.
    */
    hyperlinkExecuting?: (s: IgrSpreadsheet, e: IgrSpreadsheetHyperlinkExecutingEventArgs) => void;
    /**
     * Invoked when the selection for a
     * ig.spreadsheet.SpreadsheetPane of the
     * Spreadsheet is changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.pane" argType="object" Get the [pane](ig.spreadsheet.SpreadsheetPane) for which the selection has changed.
    */
    selectionChanged?: (s: IgrSpreadsheet, e: IgrSpreadsheetSelectionChangedEventArgs) => void;
    /**
     * Invoked when the user will be prompted with a message regarding an operation that is being performed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.canCancel" argType="bool" Get a boolean indicating if the operation that triggered the prompt can be cancelled.
     * eventArgument="ui.displayMessage" argType="bool" Get a boolean indicating if a message will be displayed to the end user.
     * eventArgument="ui.exception" argType="object" Gets the exception for the error, if there was one.
     * eventArgument="ui.message" argType="string" Get or set the message that will be displayed.
     * eventArgument="ui.trigger" argType="string" Get the [action](ig.spreadsheet.SpreadsheetUserPromptTrigger) that caused the prompt to be displayed.
    */
    userPromptDisplaying?: (s: IgrSpreadsheet, e: IgrSpreadsheetUserPromptDisplayingEventArgs) => void;
    /**
     * Invoked when a change has been made to the
     * workbook that might require a save.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * Note:
     * This event is invoked asynchronously with regards to the change(s) that
     * have occurred. Also some changes alone are not considered to dirty the Workbook even though it
     * does change state on the Workbook or one of its subobjects. An example of that would be a zoom
     * type operation (e.g. changing the
     * magnificationInNormalView).
    */
    workbookDirtied?: (s: IgrSpreadsheet, e: IgrSpreadsheetWorkbookDirtiedEventArgs) => void;
}
